Changelog
=========

0.2.1 (2019-06-15)
------------------

 - Fix env var lookups


0.2.0 (2019-06-15)
------------------

 - Support python 2 (by switching from asyncio to threading)
 - Fix reading environment variables by deferring the read to runtime


0.1.0 (2019-06-09)
------------------
 - Pass auth token when getting snaps


0.0.1 (2019-06-08)
------------------
 - Initial release
